Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(968)

Unified Diff: tools/testing/dart/multitest.dart

Issue 9649015: Change string used to annotate static type issues to 'static type warning' in multitest (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Merged up to tip Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/language/src/WrongNumberTypeArgumentsTest.dart ('k') | tools/testing/dart/test_runner.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tools/testing/dart/multitest.dart
diff --git a/tools/testing/dart/multitest.dart b/tools/testing/dart/multitest.dart
index c68fb2c401c4ef1f89dee87de8fb4c458a667080..37af902889957b93efd26dd4b22c655f37fb584e 100644
--- a/tools/testing/dart/multitest.dart
+++ b/tools/testing/dart/multitest.dart
@@ -14,7 +14,7 @@
// the normal lines of the file, and all of the multitest lines containing
// that key, in the same order as in the source file. The new test
// is expected to fail if there is a non-empty error type listed, of
// type 'compile-time error', 'runtime error', 'static type error', or
// 'dynamic type error'. The type error tests fail only in checked mode.
// There is also a test created from only the untagged lines of the file,
// with key "none", which is expected to pass. This library extracts these
@@ -26,7 +26,7 @@
// aaa
// bbb /// 02: runtime error
// ccc /// 02: continued
// ddd /// 07: static type error
// eee
//
// should create three tests:
@@ -42,13 +42,13 @@
//
// and I_am_a_multitest_07.dart
// aaa
// ddd /// 07: static type error
// eee
//
// Note that it is possible to indicate more than one acceptable outcome
-// in the case of dynamic and static type errors
+// in the case of dynamic and static type warnings
// aaa
// ddd /// 07: static type error, dynamic type error
// eee
void ExtractTestsFromMultitest(String filename,
@@ -76,7 +76,7 @@ void ExtractTestsFromMultitest(String filename,
contents = null;
Set<String> validMultitestOutcomes = new Set<String>.from(
['compile-time error', 'runtime error',
- 'static type error', 'dynamic type error']);
+ 'static type warning', 'dynamic type error']);
List<String> testTemplate = new List<String>();
testTemplate.add('// Test created from multitest named $filename.');
@@ -209,7 +209,7 @@ void DoMultitest(String filename,
openedFile.writeListSync(bytes, 0, bytes.length);
openedFile.closeSync();
Set<String> outcome = outcomes[key];
- bool enableFatalTypeErrors = outcome.contains('static type error');
+ bool enableFatalTypeErrors = outcome.contains('static type warning');
bool hasRuntimeErrors = outcome.contains('runtime error');
bool isNegative = hasRuntimeErrors
|| outcome.contains('compile-time error');
@@ -14,7 +14,7 @@
// that key, in the same order as in the source file. The new test
// is expected to fail if there is a non-empty error type listed, of
-// type 'compile-time error', 'runtime error', 'static type error', or
+// type 'compile-time error', 'runtime error', 'static type warning', or
// 'dynamic type error'. The type error tests fail only in checked mode.
// There is also a test created from only the untagged lines of the file,
@@ -26,7 +26,7 @@
// bbb /// 02: runtime error
// ccc /// 02: continued
-// ddd /// 07: static type error
+// ddd /// 07: static type warning
// eee
//
@@ -42,13 +42,13 @@
// and I_am_a_multitest_07.dart
// aaa
-// ddd /// 07: static type error
+// ddd /// 07: static type warning
// eee
//
@@ -42,13 +42,13 @@
// aaa
-// ddd /// 07: static type error, dynamic type error
+// ddd /// 07: static type warning, dynamic type error
// eee
void ExtractTestsFromMultitest(String filename,
« no previous file with comments | « tests/language/src/WrongNumberTypeArgumentsTest.dart ('k') | tools/testing/dart/test_runner.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698